@@ -9,19 +9,20 @@ from .time import ms_to_times, make_time, TIMESTAMP, timestamp_to_ms
 #: Largest timestamp allowed in SubRip, ie. 99:59:59,999.
 MAX_REPRESENTABLE_TIME = make_time(h=100) - 1
 
-def ms_to_timestamp(ms):
-    """Convert ms to 'HH:MM:SS,mmm'"""
-    # XXX throw on overflow/underflow?
-    if ms < 0: ms = 0
-    if ms > MAX_REPRESENTABLE_TIME: ms = MAX_REPRESENTABLE_TIME
-    h, m, s, ms = ms_to_times(ms)
-    return "%02d:%02d:%02d,%03d" % (h, m, s, ms)
-
 
 class SubripFormat(FormatBase):
     """SubRip Text (SRT) subtitle format implementation"""
     TIMESTAMP = TIMESTAMP
 
+    @staticmethod
+    def ms_to_timestamp(ms: int) -> str:
+        """Convert ms to 'HH:MM:SS,mmm'"""
+        # XXX throw on overflow/underflow?
+        if ms < 0: ms = 0
+        if ms > MAX_REPRESENTABLE_TIME: ms = MAX_REPRESENTABLE_TIME
+        h, m, s, ms = ms_to_times(ms)
+        return "%02d:%02d:%02d,%03d" % (h, m, s, ms)
+
     @staticmethod
     def timestamp_to_ms(groups):
         return timestamp_to_ms(groups)
@@ -73,8 +74,8 @@ class SubripFormat(FormatBase):
             # Handle the "happy" empty subtitle case, which is timestamp line followed by blank line(s)
             # followed by number line and timestamp line of the next subtitle. Fixes issue #11.
             if (len(lines) >= 2
-                    and all(re.match("\s*$", line) for line in lines[:-1])
-                    and re.match("\s*\d+\s*$", lines[-1])):
+                    and all(re.match(r"\s*$", line) for line in lines[:-1])
+                    and re.match(r"\s*\d+\s*$", lines[-1])):
                 return ""
 
             # Handle the general case.
@@ -124,8 +125,8 @@ class SubripFormat(FormatBase):
 
         lineno = 1
         for line in visible_lines:
-            start = ms_to_timestamp(line.start)
-            end = ms_to_timestamp(line.end)
+            start = cls.ms_to_timestamp(line.start)
+            end = cls.ms_to_timestamp(line.end)
             try:
                 text = prepare_text(line.text, subs.styles.get(line.style, SSAStyle.DEFAULT_STYLE))
             except ContentNotUsable:
